@@ -23,14 +23,18 @@ class TV(TMDB):
     BASE_PATH = 'tv'
     URLS = {
         'info': '/{id}',
+        'account_states': '/{id}/account_states',
         'alternative_titles': '/{id}/alternative_titles',
         'content_ratings': '/{id}/content_ratings',
         'credits': '/{id}/credits',
+        'episode_groups': '/{id}/episode_groups',
         'external_ids': '/{id}/external_ids',
         'images': '/{id}/images',
         'rating': '/{id}/rating',
         'similar': '/{id}/similar',
+        'reviews': '/{id}/reviews',
         'recommendations': '/{id}/recommendations',
+        'screened_theatrically': '/{id}/screened_theatrically',
         'translations': '/{id}/translations',
         'videos': '/{id}/videos',
         'keywords': '/{id}/keywords',
@@ -63,6 +67,24 @@ class TV(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def account_states(self, **kwargs):
+        """
+        Grab the following account states for a session:
+            - TV show rating
+            - If it belongs to your watchlist
+            - If it belongs to your favourite list
+
+        Args:
+            language: (optional) ISO 3166-1 code.
+            append_to_response: (optional) Comma separated, any tv method.
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('account_states')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
 
     def alternative_titles(self, **kwargs):
         """
@@ -80,7 +102,6 @@ class TV(TMDB):
         self._set_attrs_to_values(response)
         return response
 
-
     def content_ratings(self, **kwargs):
         """
         Get the content ratings for a TV Series.
@@ -118,6 +139,22 @@ class TV(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def episode_groups(self, **kwargs):
+        """
+        Get all of the episode groups that have been created for a TV show.
+
+        Args:
+            language: (optional) ISO 639 code.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('episode_groups')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def external_ids(self, **kwargs):
         """
         Get the external ids that we have stored for a TV series.
@@ -193,6 +230,23 @@ class TV(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def reviews(self, **kwargs):
+        """
+        Get the reviews for a TV show.
+
+        Args:
+            page: (optional) Minimum value of 1.  Expected value is an integer.
+            language: (optional) ISO 639-1 code.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('reviews')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def recommendations(self, **kwargs):
         """
         Get the recommendations for TV series for a specific TV series id.
@@ -210,6 +264,23 @@ class TV(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def screened_theatrically(self, **kwargs):
+        """
+        Get a list of seasons or episodes that have been screened in a film festival or theatre.
+
+        Args:
+            page: (optional) Minimum value of 1.  Expected value is an integer.
+            language: (optional) ISO 639-1 code.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_id_path('screened_theatrically')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def translations(self, **kwargs):
         """
         Get the list of translations that exist for a TV series. These
@@ -355,6 +426,7 @@ class TV_Seasons(TMDB):
     BASE_PATH = 'tv/{tv_id}/season/{season_number}'
     URLS = {
         'info': '',
+        'account_states': '/account_states',
         'credits': '/credits',
         'external_ids': '/external_ids',
         'images': '/images',
@@ -384,6 +456,24 @@ class TV_Seasons(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def account_states(self, **kwargs):
+        """
+        Returns all of the user ratings for the season's episodes.
+
+        Args:
+            language: (optional) ISO 639 code.
+            append_to_response: (optional) Comma separated, any TV series
+                                method.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_tv_id_season_number_path('account_states')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def credits(self, **kwargs):
         """
         Get the cast & crew credits for a TV season by season number.
@@ -460,6 +550,7 @@ class TV_Episodes(TMDB):
     BASE_PATH = 'tv/{tv_id}/season/{season_number}/episode/{episode_number}'
     URLS = {
         'info': '',
+        'account_states': '/account_states',
         'credits': '/credits',
         'external_ids': '/external_ids',
         'images': '/images',
@@ -492,6 +583,24 @@ class TV_Episodes(TMDB):
         self._set_attrs_to_values(response)
         return response
 
+    def account_states(self, **kwargs):
+        """
+        Get your rating for a episode.
+
+        Args:
+            language: (optional) ISO 639 code.
+            append_to_response: (optional) Comma separated, any TV series
+                                method.
+
+        Returns:
+            A dict respresentation of the JSON returned from the API.
+        """
+        path = self._get_tv_id_season_number_episode_number_path('account_states')
+
+        response = self._GET(path, kwargs)
+        self._set_attrs_to_values(response)
+        return response
+
     def credits(self, **kwargs):
         """
         Get the TV episode credits by combination of season and episode number.
